@@ -6,7 +6,7 @@ __copyright__ = "Copyright (C) 2014 Scott Field and Chad Galley"
 __email__     = "sfield@umassd.edu, crgalley@tapir.caltech.edu"
 __status__    = "testing"
 __author__    = "Jonathan Blackman, Scott Field, Chad Galley, Vijay Varma, Kevin Barkett"
-__version__ = "1.0.6"
+__version__ = "1.1.0"
 __license__ = """
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
@@ -1703,7 +1703,7 @@ class SurrogateEvaluator(object):
                 Skip sanity checks for inputs. Use this if you want to
                 extrapolate outside allowed range. Default: False.
 
-    taper_end_durataion:
+    taper_end_duration:
                 Taper the last TAPER_END_DURATION (M) of a time-domain waveform
                 in units of M. For exmple, passing 40 will taper the last 40M.
                 When set to None, no taper is applied
@@ -1869,7 +1869,7 @@ class SurrogateEvaluator(object):
         # this corresponds to inspiral, merger, or ringdown.
         if taper_end_duration is not None:
             h_tapered = {}
-            for mode, hlm in h.iteritems():
+            for mode, hlm in h.items():
                 # NOTE: we use a roll on window [domain[0]-100, domain[0]-50]
                 # to trick the window function into not tapering the beginning
                 # of h
